==> antos0.48.tar.gz: antos0.48/kern/debug.c <==
/*
 * debug.c
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#include <sys/config.h>
#include <sys/types.h>
#include <machine/stdarg.h>
#include <kern/proc.h>
#include <kern/lib.h>
#include <dev/console/console.h>


#ifdef DEBUG

enum{
	ENTRY_NUM=10, 
};

int debugFlag;
uint syscallEntry[ENTRY_NUM];

void saveSyscallEntry(uint entry, int syscall_num)
{
	memmove(&syscallEntry[1],syscallEntry,sizeof(uint) * (ENTRY_NUM-1));
	syscallEntry[0] = entry;
	
/****************************************************************************************************************/
	printDebug(70, "%x", entry);
/****************************************************************************************************************/
}

// parameters : n=number of prints
void printSyscallEntry(uint n)
{
	int i;

	if (n > ENTRY_NUM)
		n = ENTRY_NUM;
	printk("syscall entry\n");
	for (i = 0; i < n; ++i)
	{
		printk("%d %x ",i+1,syscallEntry[i]);
		printk("\n");
	}
}

/*
 *sӁtPf[^TCYint
 * obt@TCYŏzĕۑB
 */
void saveLog(
	const int dataNum,		//P̕ۑf[^[
	const int logNum,		//ۑ̐
	void *m_logBuf,			//ۑpobt@
	...)
{
	va_list ap;
	uint *logBuf = m_logBuf;
	int i;

	va_start(ap, m_logBuf);

	// ړ
	memmove(logBuf + dataNum, logBuf, dataNum * sizeof(uint) * (logNum - 1));

	for (i = 0; i < dataNum; ++i) {
		logBuf[i] = va_arg(ap, uint);
	}

	va_end(ap);
}

/*
 * \B
 */
void printLog(
	const int dataNum,		//P̕ۑf[^[
	const int logNum,		//ۑ̐
	void *m_logBuf)			//ۑpobt@
{
	int i, k;
	uint *logBuf = m_logBuf;
	
	printk("Print log\n");
	for (i = 0; i < logNum; ++i) {
		for (k = 0; k < dataNum; ++k) {
			printk("0x%x ", *logBuf++);
		}
		printk("\n");
	}
}

#endif

==> antos0.49.tar.gz: antos0.49/kern/debug.c <==
/*
 * debug.c
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#include <sys/config.h>
#include <sys/types.h>
#include <machine/stdarg.h>
#include <kern/proc.h>
#include <kern/lib.h>
#include <dev/console/console.h>


#ifdef DEBUG

enum{
	ENTRY_NUM=10, 
};

int debugFlag;
uint syscallEntry[ENTRY_NUM];

void saveSyscallEntry(uint entry, int syscall_num)
{
	memmove(&syscallEntry[1],syscallEntry,sizeof(uint) * (ENTRY_NUM-1));
	syscallEntry[0] = entry;

/****************************************************************************************************************/
	printDebug(70, "%x", entry);
/****************************************************************************************************************/
}

void printSyscallEntry(
	uint n)		// number of prints
{
	int i;

	if (n > ENTRY_NUM)
		n = ENTRY_NUM;
	printk("syscall entry\n");
	for (i = 0; i < n; ++i)
	{
		printk("%d %x ",i+1,syscallEntry[i]);
		printk("\n");
	}
}

/*
 *ագǡint
 * Хåեǽ۴Ĥ¸롣
 */
void saveLog(
	const int dataNum,		//¸ǡ
	const int logNum,		//¸ο
	void *m_logBuf,			//¸ѥХåե
	...)
{
	va_list ap;
	uint *logBuf = m_logBuf;
	int i;

	va_start(ap, m_logBuf);

	// ư
	memmove(logBuf + dataNum, logBuf, dataNum * sizeof(uint) * (logNum - 1));

	for (i = 0; i < dataNum; ++i) {
		logBuf[i] = va_arg(ap, uint);
	}

	va_end(ap);
}

/*
 * ɽ롣
 */
void printLog(
	const int dataNum,		//¸ǡ
	const int logNum,		//¸ο
	void *m_logBuf)			//¸ѥХåե
{
	int i, k;
	uint *logBuf = m_logBuf;
	
	printk("Print log\n");
	for (i = 0; i < logNum; ++i) {
		for (k = 0; k < dataNum; ++k) {
			printk("0x%x ", *logBuf++);
		}
		printk("\n");
	}
}

#endif
